@@ -50,10 +50,15 @@ def _stat_service(service, status=Status.BOTH):
     is_active = 'Running'
     if result != 0:
         is_active = 'Stopped'
-        result = subprocess.call([SYSTEMCTL_PATH, 'is-failed', service])
-        if result != 0:
-            is_active += " (failed)"
-    return '%s: %s, %s\n' % (service, is_active, is_enabled)
+        result = subprocess.run([SYSTEMCTL_PATH, 'is-failed', service],
+            stdout=subprocess.PIPE,
+            universal_newlines=True)
+        if result:
+            is_active += f" ({result.stdout.strip()})"
+    if status == Status.BOTH:
+      return '%s: %s, %s\n' % (service, is_active, is_enabled)
+    else:
+      return '%s: %s\n' % (service, is_active)
 
 from datetime import timedelta
 def _stat_uptime():
@@ -78,10 +83,18 @@ def _stat_temp():
     except Exception as e:
         return "\nCouldn't read temperature: %s" % e
 
+def _stat_sms():
+    try:
+        path, dirs, files = next(os.walk("/var/spool/sms/checked"))
+        return str(len(files))
+    except Exception as e:
+        return e
+
 def status(full=False):
     ret = 'Status of SMSGateway:\n'
     ret += 'Uptime: %s, Temp: %s\n' % (_stat_uptime(), _stat_temp())
     ret += 'Free space: %s\n' % _stat_df()
+    ret += 'SMS queue: %s\n' % _stat_sms()
     net_inf = NETWORK_INTERFACES_ALL if full else NETWORK_INTERFACES
     wifi_inf = WIFI_INTERFACES_ALL if full else WIFI_INTERFACES
 
