@@ -16,7 +16,7 @@ def setup_logging(service_name):
 
     std_handler = StreamHandler(sys.stdout)
     std_handler.setFormatter(syslog_formatter)
-    std_handler.setLevel(logging.INFO)
+    std_handler.setLevel(LOG_STD_LEVEL)
 
     app_log = logging.getLogger('root')
     app_log.setLevel(logging.DEBUG)
@@ -46,6 +46,13 @@ def run_cmd(args, name=None, maxlines=7, timeout=300):
 def _repl(regex, sub, text):
   return re.sub(regex, sub, text, flags=re.UNICODE)
 
+def format_sms(type, text, headers):
+    msg = f"{type}\n"
+    msg += '\n'.join([f"{k[0].upper() + k[1:]}: {v}" for k,v in headers.items() if len(k) > 1])
+    if text:
+        msg += f"\n\n{text}"
+    return msg
+
 try:
   import emoji
   use_emoji = True
